@@ -1,17 +1,17 @@
 #' @template get_goals
 #' @include mgmt.R
 #' @export
-get_goal <- function(account.id, webproperty.id, profile.id, goal.id, token) {
+get_goal <- function(accountId, webPropertyId, profileId, goalId, token) {
     path <- sprintf("management/accounts/%s/webproperties/%s/profiles/%s/goals/%s",
-                    account.id, webproperty.id, profile.id, goal.id)
+                    accountId, webPropertyId, profileId, goalId)
     get_mgmt(path, token)
 }
 
 #' @template list_goals
 #' @include mgmt.R
 #' @export
-list_goals = function(account.id = "~all", webproperty.id = "~all", profile.id = "~all", start.index = NULL, max.results = NULL, token) {
+list_goals = function(accountId = "~all", webPropertyId = "~all", profileId = "~all", start.index = NULL, max.results = NULL, token) {
     path <- sprintf("management/accounts/%s/webproperties/%s/profiles/%s/goals",
-                    account.id, webproperty.id, profile.id)
+                    accountId, webPropertyId, profileId)
     list_mgmt(path, list(start.index = start.index, max.results = max.results), token)
 }
