@@ -4,6 +4,7 @@ api_base_path <- "analytics"
 api_version <- "v3"
 
 # Build URL for Google Analytics request
+#' @importFrom httr modify_url
 #' @include utils.R
 get_url <- function(path = NULL, query = NULL) {
     path <- c(api_base_path, api_version, path)
@@ -15,6 +16,6 @@ get_url <- function(path = NULL, query = NULL) {
         params <- gsub(".", "-", params, fixed = TRUE)
         names(query) <- params
     }
-    url <- httr::modify_url(api_base_url, path = path, query = query)
+    url <- modify_url(api_base_url, path = path, query = query)
     return(url)
 }
